summaryrefslogtreecommitdiff
path: root/usr/src/lib
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/lib')
-rw-r--r--usr/src/lib/pkcs11/libpkcs11/common/pkcs11Conf.c6
-rw-r--r--usr/src/lib/pkcs11/libpkcs11/common/pkcs11Global.h4
2 files changed, 5 insertions, 5 deletions
diff --git a/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Global.h b/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Global.h
index a5ce0a2a0d..5c49b3f9dc 100644
--- a/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Global.h
+++ b/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Global.h
@@ -20,7 +20,7 @@
* CDDL HEADER END
*/
/*
- * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -49,7 +49,7 @@ extern CK_SLOT_ID fast_slot;
/* CK_INFO: Information about cryptoki */
#define CRYPTOKI_VERSION_MAJOR 2
-#define CRYPTOKI_VERSION_MINOR 11
+#define CRYPTOKI_VERSION_MINOR 20
#define CRYPTOKI_VERSION_WARN_MINOR 10
#define MANUFACTURER_ID "Sun Microsystems, Inc. "
#define LIBRARY_DESCRIPTION "Sun Crypto PKCS#11 Library "
diff --git a/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Conf.c b/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Conf.c
index 57f01daec2..a4a357ef89 100644
--- a/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Conf.c
+++ b/usr/src/lib/pkcs11/libpkcs11/common/pkcs11Conf.c
@@ -20,7 +20,7 @@
* CDDL HEADER END
*/
/*
- * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -434,7 +434,7 @@ pkcs11_slot_mapping(uentrylist_t *pplist, CK_VOID_PTR pInitArgs)
}
/*
* Warn the administrator that a provider with
* a significantly older or newer version of
* CRYPTOKI is being used. It should not cause
* problems, but logging a warning makes it easier
@@ -444,7 +444,7 @@ pkcs11_slot_mapping(uentrylist_t *pplist, CK_VOID_PTR pInitArgs)
CRYPTOKI_VERSION_WARN_MINOR) ||
(prov_info.cryptokiVersion.minor >
CRYPTOKI_VERSION_MINOR)) {
- cryptoerror(LOG_INFO,
+ cryptoerror(LOG_DEBUG,
"libpkcs11: %s CRYPTOKI minor version, %d, may "
"not be compatible with minor version %d.",
fullpath, prov_info.cryptokiVersion.minor,
@@ -434,7 +434,7 @@ pkcs11_slot_mapping(uentrylist_t *pplist, CK_VOID_PTR pInitArgs)
}
/*
- * Warn the administrator that a provider with
+ * Warn the administrator (at debug) that a provider with
* a significantly older or newer version of
* CRYPTOKI is being used. It should not cause